@@ -28,47 +28,30 @@
 #include "nautilus-desktop-icon-file.h"
 #include "nautilus-directory-private.h"
 #include "nautilus-desktop-directory.h"
-
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-vfs-extensions.h>
-#include <gtk/gtksignal.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-trash-monitor.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <string.h>
 
-#define TRASH_EMPTY_ICON "gnome-fs-trash-empty"
-#define TRASH_FULL_ICON "gnome-fs-trash-full"
-
 struct NautilusDesktopLinkDetails {
 	NautilusDesktopLinkType type;
         char *filename;
 	char *display_name;
-	char *activation_uri;
-	char *icon;
+	GFile *activation_location;
+	GIcon *icon;
 
 	NautilusDesktopIconFile *icon_file;
 	
 	/* Just for trash icons: */
 	gulong trash_state_handler;
 
-	/* Just for volume icons: */
-	GnomeVFSVolume *volume;
+	/* Just for mount icons: */
+	GMount *mount;
 };
 
-static void nautilus_desktop_link_init       (gpointer              object,
-					      gpointer              klass);
-static void nautilus_desktop_link_class_init (gpointer              klass);
-static void trash_state_changed_callback     (NautilusTrashMonitor *trash_monitor,
-					      gboolean              state,
-					      gpointer              callback_data);
-static void nautilus_desktop_link_changed    (NautilusDesktopLink  *link);
-
-EEL_CLASS_BOILERPLATE (NautilusDesktopLink,
-		       nautilus_desktop_link,
-		       G_TYPE_OBJECT)
+G_DEFINE_TYPE(NautilusDesktopLink, nautilus_desktop_link, G_TYPE_OBJECT)
 
 static void
 create_icon_file (NautilusDesktopLink *link)
@@ -76,6 +59,32 @@ create_icon_file (NautilusDesktopLink *link)
 	link->details->icon_file = nautilus_desktop_icon_file_new (link);
 }
 
+static void
+nautilus_desktop_link_changed (NautilusDesktopLink *link)
+{
+	if (link->details->icon_file != NULL) {
+		nautilus_desktop_icon_file_update (link->details->icon_file);
+	}
+}
+
+static void
+trash_state_changed_callback (NautilusTrashMonitor *trash_monitor,
+			      gboolean state,
+			      gpointer callback_data)
+{
+	NautilusDesktopLink *link;
+
+	link = NAUTILUS_DESKTOP_LINK (callback_data);
+	g_assert (link->details->type == NAUTILUS_DESKTOP_LINK_TRASH);
+
+	if (link->details->icon) {
+		g_object_unref (link->details->icon);
+	}
+	link->details->icon = nautilus_trash_monitor_get_icon ();
+
+	nautilus_desktop_link_changed (link);
+}
+
 static void
 home_name_changed (gpointer callback_data)
 {
@@ -112,13 +121,23 @@ trash_name_changed (gpointer callback_data)
 	link = NAUTILUS_DESKTOP_LINK (callback_data);
 	g_assert (link->details->type == NAUTILUS_DESKTOP_LINK_TRASH);
 
-	
 	g_free (link->details->display_name);
 	link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_TRASH_NAME);
 	nautilus_desktop_link_changed (link);
 }
 
+static void
+network_name_changed (gpointer callback_data)
+{
+	NautilusDesktopLink *link;
 
+	link = NAUTILUS_DESKTOP_LINK (callback_data);
+	g_assert (link->details->type == NAUTILUS_DESKTOP_LINK_NETWORK);
+
+	g_free (link->details->display_name);
+	link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_NETWORK_NAME);
+	nautilus_desktop_link_changed (link);
+}
 
 NautilusDesktopLink *
 nautilus_desktop_link_new (NautilusDesktopLinkType type)
@@ -132,8 +151,8 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 	case NAUTILUS_DESKTOP_LINK_HOME:
 		link->details->filename = g_strdup ("home");
 		link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_HOME_NAME);
-		link->details->activation_uri = nautilus_get_home_directory_uri ();
-		link->details->icon = g_strdup ("gnome-fs-home");
+		link->details->activation_location = g_file_new_for_path (g_get_home_dir ());
+		link->details->icon = g_themed_icon_new ("user-home");
 
 		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_HOME_NAME,
 					      home_name_changed,
@@ -143,12 +162,10 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 		
 	case NAUTILUS_DESKTOP_LINK_COMPUTER:
 		link->details->filename = g_strdup ("computer");
-
 		link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME);
-		
-		link->details->activation_uri = g_strdup ("computer:///");
+		link->details->activation_location = g_file_new_for_uri ("computer:///");
 		/* TODO: This might need a different icon: */
-		link->details->icon = g_strdup ("gnome-fs-client");
+		link->details->icon = g_themed_icon_new ("gnome-fs-client");
 
 		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME,
 					      computer_name_changed,
@@ -159,12 +176,8 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 	case NAUTILUS_DESKTOP_LINK_TRASH:
 		link->details->filename = g_strdup ("trash");
 		link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_TRASH_NAME);
-		link->details->activation_uri = g_strdup (EEL_TRASH_URI);
-		if (nautilus_trash_monitor_is_empty ()) {
-			link->details->icon = g_strdup (TRASH_EMPTY_ICON);
-		} else {
-			link->details->icon = g_strdup (TRASH_FULL_ICON);
-		}
+		link->details->activation_location = g_file_new_for_uri (EEL_TRASH_URI);
+		link->details->icon = nautilus_trash_monitor_get_icon ();
 		
 		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_TRASH_NAME,
 					      trash_name_changed,
@@ -176,13 +189,17 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 
 	case NAUTILUS_DESKTOP_LINK_NETWORK:
 		link->details->filename = g_strdup ("network");
-		link->details->display_name = g_strdup (_("Network Servers"));
-		link->details->activation_uri = g_strdup ("network:///");
-		link->details->icon = g_strdup ("gnome-fs-network");
+		link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_NETWORK_NAME);
+		link->details->activation_location = g_file_new_for_uri ("network:///");
+		link->details->icon = g_themed_icon_new ("gnome-fs-network");
+
+		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_NETWORK_NAME,
+					      network_name_changed,
+					      link);
 		break;
 
 	default:
-	case NAUTILUS_DESKTOP_LINK_VOLUME:
+	case NAUTILUS_DESKTOP_LINK_MOUNT:
 		g_assert_not_reached();
 	}
 
@@ -192,56 +209,59 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 }
 
 NautilusDesktopLink *
-nautilus_desktop_link_new_from_volume (GnomeVFSVolume *volume)
+nautilus_desktop_link_new_from_mount (GMount *mount)
 {
 	NautilusDesktopLink *link;
-	GnomeVFSDrive *drive;
+	GVolume *volume;
 	char *name, *filename;
 
 	link = NAUTILUS_DESKTOP_LINK (g_object_new (NAUTILUS_TYPE_DESKTOP_LINK, NULL));
 	
-	link->details->type = NAUTILUS_DESKTOP_LINK_VOLUME;
+	link->details->type = NAUTILUS_DESKTOP_LINK_MOUNT;
 
-	link->details->volume = gnome_vfs_volume_ref (volume);
+	link->details->mount = g_object_ref (mount);
 
 	/* We try to use the drive name to get somewhat stable filenames
 	   for metadata */
-	drive = gnome_vfs_volume_get_drive (volume);
-	if (drive != NULL) {
-		name = gnome_vfs_drive_get_display_name (drive);
+	volume = g_mount_get_volume (mount);
+	if (volume != NULL) {
+		name = g_volume_get_name (volume);
+		g_object_unref (volume);
 	} else {
-		name = gnome_vfs_volume_get_display_name (volume);
+		name = g_mount_get_name (mount);
 	}
-	gnome_vfs_drive_unref (drive);
 
-	filename = g_strconcat (name, ".volume", NULL);
+	/* Replace slashes in name */
+	filename = g_strconcat (g_strdelimit (name, "/", '-'), ".volume", NULL);
 	link->details->filename =
 		nautilus_desktop_link_monitor_make_filename_unique (nautilus_desktop_link_monitor_get (),
 								    filename);
 	g_free (filename);
 	g_free (name);
 	
-	link->details->display_name = gnome_vfs_volume_get_display_name (volume);
+	link->details->display_name = g_mount_get_name (mount);
+	
+	link->details->activation_location = g_mount_get_root (mount);
+	link->details->icon = g_mount_get_icon (mount);
 	
-	link->details->activation_uri = gnome_vfs_volume_get_activation_uri (volume);
-	link->details->icon = gnome_vfs_volume_get_icon (volume);
-
 	create_icon_file (link);
 
 	return link;
 }
 
-GnomeVFSVolume *
-nautilus_desktop_link_get_volume (NautilusDesktopLink *link)
+GMount *
+nautilus_desktop_link_get_mount (NautilusDesktopLink *link)
 {
-	return gnome_vfs_volume_ref (link->details->volume);
+	if (link->details->mount) {
+		return g_object_ref (link->details->mount);
+	}
+	return NULL;
 }
 
-
 NautilusDesktopLinkType
-nautilus_desktop_link_get_link_type  (NautilusDesktopLink *link)
+nautilus_desktop_link_get_link_type (NautilusDesktopLink *link)
 {
-  return link->details->type;
+	return link->details->type;
 }
 
 char *
@@ -256,16 +276,22 @@ nautilus_desktop_link_get_display_name (NautilusDesktopLink *link)
 	return g_strdup (link->details->display_name);
 }
 
-char *
+GIcon *
 nautilus_desktop_link_get_icon (NautilusDesktopLink *link)
 {
-	return g_strdup (link->details->icon);
+	if (link->details->icon != NULL) {
+		return g_object_ref (link->details->icon);
+	}
+	return NULL;
 }
 
-char *
-nautilus_desktop_link_get_activation_uri (NautilusDesktopLink *link)
+GFile *
+nautilus_desktop_link_get_activation_location (NautilusDesktopLink *link)
 {
-	return g_strdup (link->details->activation_uri);
+	if (link->details->activation_location) {
+		return g_object_ref (link->details->activation_location);
+	}
+	return NULL;
 }
 
 gboolean
@@ -276,40 +302,12 @@ nautilus_desktop_link_get_date (NautilusDesktopLink *link,
 	return FALSE;
 }
 
-static void
-nautilus_desktop_link_changed (NautilusDesktopLink *link)
-{
-	if (link->details->icon_file != NULL) {
-		nautilus_desktop_icon_file_update (link->details->icon_file);
-	}
-}
-
-static void
-trash_state_changed_callback (NautilusTrashMonitor *trash_monitor,
-			      gboolean state,
-			      gpointer callback_data)
-{
-	NautilusDesktopLink *link;
-
-	link = NAUTILUS_DESKTOP_LINK (callback_data);
-	g_assert (link->details->type == NAUTILUS_DESKTOP_LINK_TRASH);
-
-	g_free (link->details->icon);
-	
-	if (state) {
-		link->details->icon = g_strdup (TRASH_EMPTY_ICON);
-	} else {
-		link->details->icon = g_strdup (TRASH_FULL_ICON);
-	}
-
-	nautilus_desktop_link_changed (link);
-}
-
 gboolean
 nautilus_desktop_link_can_rename (NautilusDesktopLink     *link)
 {
 	return (link->details->type == NAUTILUS_DESKTOP_LINK_HOME ||
 		link->details->type == NAUTILUS_DESKTOP_LINK_TRASH ||
+		link->details->type == NAUTILUS_DESKTOP_LINK_NETWORK ||
 		link->details->type == NAUTILUS_DESKTOP_LINK_COMPUTER);
 }
 
@@ -330,6 +328,10 @@ nautilus_desktop_link_rename (NautilusDesktopLink     *link,
 		eel_preferences_set (NAUTILUS_PREFERENCES_DESKTOP_TRASH_NAME,
 				     name);
 		break;
+	case NAUTILUS_DESKTOP_LINK_NETWORK:
+		eel_preferences_set (NAUTILUS_PREFERENCES_DESKTOP_NETWORK_NAME,
+				     name);
+		break;
 	default:
 		g_assert_not_reached ();
 		/* FIXME: Do we want volume renaming?
@@ -340,16 +342,13 @@ nautilus_desktop_link_rename (NautilusDesktopLink     *link,
 	return TRUE;
 }
 
-
 static void
-nautilus_desktop_link_init (gpointer object, gpointer klass)
+nautilus_desktop_link_init (NautilusDesktopLink *link)
 {
-	NautilusDesktopLink *link;
-
-	link = NAUTILUS_DESKTOP_LINK (object);
-
-	link->details = g_new0 (NautilusDesktopLinkDetails, 1);
-}	
+	link->details = G_TYPE_INSTANCE_GET_PRIVATE (link,
+						     NAUTILUS_TYPE_DESKTOP_LINK,
+						     NautilusDesktopLinkDetails);
+}
 
 static void
 desktop_link_finalize (GObject *object)
@@ -387,26 +386,36 @@ desktop_link_finalize (GObject *object)
 						 link);
 	}
 
-	if (link->details->type == NAUTILUS_DESKTOP_LINK_VOLUME) {
-		gnome_vfs_volume_unref (link->details->volume);
+	if (link->details->type == NAUTILUS_DESKTOP_LINK_NETWORK) {
+		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DESKTOP_NETWORK_NAME,
+						 network_name_changed,
+						 link);
+	}
+
+	if (link->details->type == NAUTILUS_DESKTOP_LINK_MOUNT) {
+		g_object_unref (link->details->mount);
 	}
 
 	g_free (link->details->filename);
 	g_free (link->details->display_name);
-	g_free (link->details->activation_uri);
-	g_free (link->details->icon);
-	g_free (link->details);
+	if (link->details->activation_location) {
+		g_object_unref (link->details->activation_location);
+	}
+	if (link->details->icon) {
+		g_object_unref (link->details->icon);
+	}
 
-	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (nautilus_desktop_link_parent_class)->finalize (object);
 }
 
 static void
-nautilus_desktop_link_class_init (gpointer klass)
+nautilus_desktop_link_class_init (NautilusDesktopLinkClass *klass)
 {
 	GObjectClass *object_class;
 
 	object_class = G_OBJECT_CLASS (klass);
-	
+
 	object_class->finalize = desktop_link_finalize;
 
+	g_type_class_add_private (object_class, sizeof(NautilusDesktopLinkDetails));
 }
