@@ -28,7 +28,6 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-result.h>
 #include <libnautilus-private/nautilus-debug-log.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <eel/eel-string.h>
@@ -37,41 +36,39 @@
 #define NEW_NAME_TAG "Nautilus: new name"
 #define MAXIMUM_DISPLAYED_FILE_NAME_LENGTH	50
 
-static void finish_rename (NautilusFile *file, gboolean stop_timer, GnomeVFSResult result);
+static void finish_rename (NautilusFile *file, gboolean stop_timer, GError *error);
 
 void
 fm_report_error_loading_directory (NautilusFile *file,
-			           GnomeVFSResult error,
-				   const char *error_message,
+				   GError *error,
 			           GtkWindow *parent_window)
 {
 	char *file_name;
 	char *message;
 
-	if (error_message == NULL && error == GNOME_VFS_OK) {
+	if (error == NULL ||
+	    error->message == NULL) {
 		return;
 	}
 
 	file_name = nautilus_file_get_display_name (file);
-
-	if (!error_message) {
-		switch (error) {
-		case GNOME_VFS_ERROR_ACCESS_DENIED:
+	
+	if (error->domain == G_IO_ERROR) {
+		switch (error->code) {
+		case G_IO_ERROR_PERMISSION_DENIED:
 			message = g_strdup_printf (_("You do not have the permissions necessary to view the contents of \"%s\"."),
 						   file_name);
 			break;
-		case GNOME_VFS_ERROR_NOT_FOUND:
+		case G_IO_ERROR_NOT_FOUND:
 			message = g_strdup_printf (_("\"%s\" couldn't be found. Perhaps it has recently been deleted."),
 						   file_name);
 			break;
 		default:
-			/* We should invent decent error messages for every case we actually experience. */
-			g_warning ("Hit unhandled case %d (%s) in fm_report_error_loading_directory", 
-				   error, gnome_vfs_result_to_string (error));
-			message = g_strdup_printf (_("Sorry, couldn't display all the contents of \"%s\"."), file_name);
+			message = g_strdup_printf (_("Sorry, couldn't display all the contents of \"%s\": %s"), file_name,
+						   error->message);
 		}
 	} else {
-		message = g_strdup (error_message);
+		message = g_strdup (error->message);
 	}
 
 	eel_show_error_dialog (_("The folder contents could not be displayed."), message, parent_window);
@@ -83,17 +80,13 @@ fm_report_error_loading_directory (NautilusFile *file,
 void
 fm_report_error_renaming_file (NautilusFile *file,
 			       const char *new_name,
-			       GnomeVFSResult error,
+			       GError *error,
 			       GtkWindow *parent_window)
 {
 	char *original_name, *original_name_truncated;
 	char *new_name_truncated;
 	char *message;
 
-	if (error == GNOME_VFS_OK) {
-		return;
-	}
-
 	/* Truncate names for display since very long file names with no spaces
 	 * in them won't get wrapped, and can create insanely wide dialog boxes.
 	 */
@@ -102,47 +95,50 @@ fm_report_error_renaming_file (NautilusFile *file,
 	g_free (original_name);
 	
 	new_name_truncated = eel_str_middle_truncate (new_name, MAXIMUM_DISPLAYED_FILE_NAME_LENGTH);
-	
-	switch (error) {
-	case GNOME_VFS_ERROR_FILE_EXISTS:
-		message = g_strdup_printf (_("The name \"%s\" is already used in this folder. "
-					     "Please use a different name."), 
-					   new_name_truncated);
-		break;
-	case GNOME_VFS_ERROR_NOT_FOUND:
-		message = g_strdup_printf (_("There is no \"%s\" in this folder. "
-					     "Perhaps it was just moved or deleted?"), 
-					   original_name_truncated);
-		break;
-	case GNOME_VFS_ERROR_ACCESS_DENIED:
-		message = g_strdup_printf (_("You do not have the permissions necessary to rename \"%s\"."),
-					   original_name_truncated);
-		break;
-	case GNOME_VFS_ERROR_NOT_PERMITTED:
-		if (strchr (new_name, '/') != NULL) {
-			message = g_strdup_printf (_("The name \"%s\" is not valid because it contains the character \"/\". "
-						     "Please use a different name."),
-						   new_name_truncated);
-		} else {
-			message = g_strdup_printf (_("The name \"%s\" is not valid. "
-						     "Please use a different name."),
-						   new_name_truncated);
-		}
-		break;
-	case GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM:
-		message = g_strdup_printf (_("Couldn't change the name of \"%s\" because it is on a read-only disk"),
-					   original_name_truncated);
-		break;
-	default:
-		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_renaming_file", 
-			   error, gnome_vfs_result_to_string (error));
-		/* fall through */
-	case GNOME_VFS_ERROR_GENERIC:
-		message = g_strdup_printf (_("Sorry, couldn't rename \"%s\" to \"%s\"."),
-					   original_name_truncated, new_name_truncated);
-	}
 
+	message = NULL;
+	if (error->domain == G_IO_ERROR) {
+		switch (error->code) {
+		case G_IO_ERROR_EXISTS:
+			message = g_strdup_printf (_("The name \"%s\" is already used in this folder. "
+						     "Please use a different name."), 
+						   new_name_truncated);
+			break;
+		case G_IO_ERROR_NOT_FOUND:
+			message = g_strdup_printf (_("There is no \"%s\" in this folder. "
+						     "Perhaps it was just moved or deleted?"), 
+						   original_name_truncated);
+			break;
+		case G_IO_ERROR_PERMISSION_DENIED:
+			message = g_strdup_printf (_("You do not have the permissions necessary to rename \"%s\"."),
+						   original_name_truncated);
+			break;
+		case G_IO_ERROR_INVALID_FILENAME:
+			if (strchr (new_name, '/') != NULL) {
+				message = g_strdup_printf (_("The name \"%s\" is not valid because it contains the character \"/\". "
+							     "Please use a different name."),
+							   new_name_truncated);
+			} else {
+				message = g_strdup_printf (_("The name \"%s\" is not valid. "
+							     "Please use a different name."),
+							   new_name_truncated);
+			}
+			break;
+		default:
+			break;
+		}
+	}
+	
+	if (message == NULL) {
+		/* We should invent decent error messages for every case we actually experience. */
+		g_warning ("Hit unhandled case %s:%d in fm_report_error_renaming_file", 
+			   g_quark_to_string (error->domain), error->code);
+		/* fall through */
+		message = g_strdup_printf (_("Sorry, couldn't rename \"%s\" to \"%s\": %s"), 
+					   original_name_truncated, new_name_truncated,
+					   error->message);
+	}
+	
 	g_free (original_name_truncated);
 	g_free (new_name_truncated);
 
@@ -152,67 +148,61 @@ fm_report_error_renaming_file (NautilusFile *file,
 
 void
 fm_report_error_setting_group (NautilusFile *file,
-			       GnomeVFSResult error,
+			       GError *error,
 			       GtkWindow *parent_window)
 {
 	char *file_name;
 	char *message;
 
-	if (error == GNOME_VFS_OK) {
+	if (error == NULL) {
 		return;
 	}
 
 	file_name = nautilus_file_get_display_name (file);
 
-	switch (error) {
-	case GNOME_VFS_ERROR_NOT_PERMITTED:
-		message = g_strdup_printf (_("You do not have the permissions necessary to change the group of \"%s\"."),
-					   file_name);
-		break;
-	case GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM:
-		message = g_strdup_printf (_("Couldn't change the group of \"%s\" because it is on a read-only disk"),
-					   file_name);
-		break;
-	default:
-		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_group", 
-			   error, gnome_vfs_result_to_string (error));
-		file_name = nautilus_file_get_display_name (file);
-		message = g_strdup_printf (_("Sorry, couldn't change the group of \"%s\"."), file_name);
-		g_free (file_name);
+	message = NULL;
+	if (error->domain == G_IO_ERROR) {
+		switch (error->code) {
+		case G_IO_ERROR_PERMISSION_DENIED:
+			message = g_strdup_printf (_("You do not have the permissions necessary to change the group of \"%s\"."),
+						   file_name);
+			break;
+		default:
+			break;
+		}
 	}
-
+			
+	if (message == NULL) {
+		/* We should invent decent error messages for every case we actually experience. */
+		g_warning ("Hit unhandled case %s:%d in fm_report_error_setting_group", 
+			   g_quark_to_string (error->domain), error->code);
+		/* fall through */
+		message = g_strdup_printf (_("Sorry, couldn't change the group of \"%s\": %s"), file_name,
+					   error->message);
+	}
+	
+	
 	eel_show_error_dialog (_("The group could not be changed."), message, parent_window);
-
+	
 	g_free (file_name);
 	g_free (message);
-}		
+}
 
 void
 fm_report_error_setting_owner (NautilusFile *file,
-			       GnomeVFSResult error,
+			       GError *error,
 			       GtkWindow *parent_window)
 {
 	char *file_name;
 	char *message;
 
-	if (error == GNOME_VFS_OK) {
+	if (error == NULL) {
 		return;
 	}
 
 	file_name = nautilus_file_get_display_name (file);
 
-	switch (error) {
-	case GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM:
-		message = g_strdup_printf (_("Couldn't change the owner of \"%s\" because it is on a read-only disk"),
-					   file_name);
-		break;
-	default:
-		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_owner", 
-			   error, gnome_vfs_result_to_string (error));
-		message = g_strdup_printf (_("Sorry, couldn't change the owner of \"%s\"."), file_name);
-	}
+	message = g_strdup_printf (_("Sorry, couldn't change the owner of \"%s\": %s"), file_name, error->message);
 
 	eel_show_error_dialog (_("The owner could not be changed."), message, parent_window);
 
@@ -222,29 +212,19 @@ fm_report_error_setting_owner (NautilusFile *file,
 
 void
 fm_report_error_setting_permissions (NautilusFile *file,
-			       	     GnomeVFSResult error,
+			       	     GError *error,
 			       	     GtkWindow *parent_window)
 {
 	char *file_name;
 	char *message;
 
-	if (error == GNOME_VFS_OK) {
+	if (error == NULL) {
 		return;
 	}
 
 	file_name = nautilus_file_get_display_name (file);
 
-	switch (error) {
-	case GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM:
-		message = g_strdup_printf (_("Couldn't change the permissions of \"%s\" because it is on a read-only disk"),
-					   file_name);
-		break;
-	default:
-		/* We should invent decent error messages for every case we actually experience. */
-		g_warning ("Hit unhandled case %d (%s) in fm_report_error_setting_permissions", 
-			   error, gnome_vfs_result_to_string (error));
-		message = g_strdup_printf (_("Sorry, couldn't change the permissions of \"%s\"."), file_name);
-	}
+	message = g_strdup_printf (_("Sorry, couldn't change the permissions of \"%s\": %s"), file_name, error->message);
 
 	eel_show_error_dialog (_("The permissions could not be changed."), message, parent_window);
 
@@ -266,7 +246,8 @@ fm_rename_data_free (FMRenameData *data)
 }
 
 static void
-rename_callback (NautilusFile *file, GnomeVFSResult result, gpointer callback_data)
+rename_callback (NautilusFile *file, GFile *result_location,
+		 GError *error, gpointer callback_data)
 {
 	FMRenameData *data;
 
@@ -276,20 +257,27 @@ rename_callback (NautilusFile *file, GnomeVFSResult result, gpointer callback_da
 	data = g_object_get_data (G_OBJECT (file), NEW_NAME_TAG);
 	g_assert (data != NULL);
 
-	/* If rename failed, notify the user. */
-	fm_report_error_renaming_file (file, data->name, result, NULL);
+	if (error &&
+	    !(error->domain == G_IO_ERROR && error->code == G_IO_ERROR_CANCELLED)) {
+		/* If rename failed, notify the user. */
+		fm_report_error_renaming_file (file, data->name, error, NULL);
+	}
 
-	finish_rename (file, TRUE, result);
+	finish_rename (file, TRUE, error);
 }
 
 static void
 cancel_rename_callback (gpointer callback_data)
 {
-	finish_rename (NAUTILUS_FILE (callback_data), FALSE, GNOME_VFS_ERROR_CANCELLED);
+	GError *error;
+	
+	error = g_error_new (G_IO_ERROR, G_IO_ERROR_CANCELLED, "Cancelled");
+	finish_rename (NAUTILUS_FILE (callback_data), FALSE, error);
+	g_error_free (error);
 }
 
 static void
-finish_rename (NautilusFile *file, gboolean stop_timer, GnomeVFSResult result)
+finish_rename (NautilusFile *file, gboolean stop_timer, GError *error)
 {
 	FMRenameData *data;
 
@@ -305,7 +293,7 @@ finish_rename (NautilusFile *file, gboolean stop_timer, GnomeVFSResult result)
 	}
 
 	if (data->callback != NULL) {
-		data->callback (file, result, data->callback_data);
+		data->callback (file, NULL, error, data->callback_data);
 	}
 	
 	/* Let go of file name. */
@@ -321,12 +309,15 @@ fm_rename_file (NautilusFile *file,
 	char *old_name, *wait_message;
 	FMRenameData *data;
 	char *uri;
+	GError *error;
 
 	g_return_if_fail (NAUTILUS_IS_FILE (file));
 	g_return_if_fail (new_name != NULL);
 
 	/* Stop any earlier rename that's already in progress. */
-	finish_rename (file, TRUE, GNOME_VFS_ERROR_CANCELLED);
+	error = g_error_new (G_IO_ERROR, G_IO_ERROR_CANCELLED, "Cancelled");
+	finish_rename (file, TRUE, error);
+	g_error_free (error);
 
 	data = g_new0 (FMRenameData, 1);
 	data->name = g_strdup (new_name);
