@@ -31,7 +31,9 @@
 
 #include "nautilus-actions.h"
 #include "nautilus-application.h"
+#ifdef GIO_CONVERSION_DONE
 #include "nautilus-connect-server-dialog.h"
+#endif
 #include "nautilus-file-management-properties.h"
 #include "nautilus-property-browser.h"
 #include "nautilus-window-manage-views.h"
@@ -39,35 +41,22 @@
 #include "nautilus-window-private.h"
 #include "nautilus-desktop-window.h"
 #include "nautilus-search-bar.h"
-#include <eel/eel-debug.h>
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-gnome-extensions.h>
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-stock-dialogs.h>
-#include <eel/eel-string.h>
-#include <eel/eel-vfs-extensions.h>
-#include <eel/eel-xml-extensions.h>
-#include <libxml/parser.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkenums.h>
-#include <libgnome/gnome-help.h>
+#include <gtk/gtkversion.h>
+#include <gio/gio.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-help.h>
-#include <libgnomeui/gnome-uidefs.h>
-#include <libgnomevfs/gnome-vfs-file-info.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-ui-utilities.h>
-#include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-search-engine.h>
 #include <libnautilus-private/nautilus-signaller.h>
+#include <string.h>
 
 #define MENU_PATH_EXTENSION_ACTIONS                     "/MenuBar/File/Extension Actions"
 #define POPUP_PATH_EXTENSION_ACTIONS                     "/background/Before Zoom Items/Extension Actions"
@@ -127,16 +116,16 @@ static void
 activate_bookmark_in_menu_item (GtkAction *action, gpointer user_data)
 {
         BookmarkHolder *holder;
-        char *uri;
+        GFile *location;
 
         holder = (BookmarkHolder *)user_data;
 
 	if (nautilus_bookmark_uri_known_not_to_exist (holder->bookmark)) {
 		holder->failed_callback (holder->window, holder->bookmark);
 	} else {
-	        uri = nautilus_bookmark_get_uri (holder->bookmark);
-	        nautilus_window_go_to (holder->window, uri);
-	        g_free (uri);
+	        location = nautilus_bookmark_get_location (holder->bookmark);
+	        nautilus_window_go_to (holder->window, location);
+	        g_object_unref (location);
         }
 }
 
@@ -151,8 +140,9 @@ nautilus_menus_append_bookmark_to_menu (NautilusWindow *window,
 					GCallback refresh_callback,
 					NautilusBookmarkFailedCallback failed_callback)
 {
-	BookmarkHolder *bookmark_holder;		
-	char *raw_name, *display_name, *truncated_name, *action_name;
+	BookmarkHolder *bookmark_holder;
+	char action_name[128];
+	char *name;
 	GdkPixbuf *pixbuf;
 	GtkAction *action;
 
@@ -160,25 +150,15 @@ nautilus_menus_append_bookmark_to_menu (NautilusWindow *window,
 	g_assert (NAUTILUS_IS_BOOKMARK (bookmark));
 
 	bookmark_holder = bookmark_holder_new (bookmark, window, refresh_callback, failed_callback);
-
-	/* We double the underscores here to escape them so gtk+ will know they are
-	 * not keyboard accelerator character prefixes. If we ever find we need to
-	 * escape more than just the underscores, we'll add a menu helper function
-	 * instead of a string utility. (Like maybe escaping control characters.)
-	 */
-	raw_name = nautilus_bookmark_get_name (bookmark);
-	truncated_name = eel_truncate_text_for_menu_item (raw_name);
-	display_name = eel_str_double_underscores (truncated_name);
-	g_free (raw_name);
-	g_free (truncated_name);
+	name = nautilus_bookmark_get_name (bookmark);
 
 	/* Create menu item with pixbuf */
 	pixbuf = nautilus_bookmark_get_pixbuf (bookmark, GTK_ICON_SIZE_MENU);
 
-	action_name = g_strdup_printf ("bookmark_%s_%d", parent_id, index_in_parent);
+	g_snprintf (action_name, sizeof (action_name), "%s%d", parent_id, index_in_parent);
 
 	action = gtk_action_new (action_name,
-				 display_name,
+				 name,
 				 _("Go to the location specified by this bookmark"),
 				 NULL);
 	
@@ -205,8 +185,7 @@ nautilus_menus_append_bookmark_to_menu (NautilusWindow *window,
 			       FALSE);
 
 	g_object_unref (pixbuf);
-	g_free (action_name);
-	g_free (display_name);
+	g_free (name);
 }
 
 static void
@@ -216,6 +195,8 @@ action_close_window_callback (GtkAction *action,
 	nautilus_window_close (NAUTILUS_WINDOW (user_data));
 }
 
+#ifdef GIO_CONVERSION_DONE
+
 static void
 action_connect_to_server_callback (GtkAction *action, 
 				   gpointer user_data)
@@ -223,25 +204,34 @@ action_connect_to_server_callback (GtkAction *action,
 	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
 	GtkWidget *dialog;
 	char *location;
-	location = nautilus_window_get_location (window);
+	location = nautilus_window_get_location_uri (window);
 	dialog = nautilus_connect_server_dialog_new (window, location);
 	g_free (location);
 
 	gtk_widget_show (dialog);
 }
 
+#endif
+
 static gboolean
 have_burn_uri (void)
 {
 	static gboolean initialized = FALSE;
 	static gboolean res;
-	GnomeVFSURI *uri;
+	GVfs *vfs;
+	int i;
+	const gchar * const * supported_uri_schemes;
 
 	if (!initialized) {
-		uri = gnome_vfs_uri_new ("burn:///");
-		res = uri != NULL;
-		if (uri != NULL) {
-			gnome_vfs_uri_unref (uri);
+		vfs = g_vfs_get_default ();
+		supported_uri_schemes = g_vfs_get_supported_uri_schemes (vfs);
+
+		res = FALSE;
+		for (i = 0; supported_uri_schemes != NULL && supported_uri_schemes[i] != NULL; i++) {
+			if (strcmp ("burn", supported_uri_schemes[i]) == 0) {
+				res = TRUE;
+				break;
+			}
 		}
 		initialized = TRUE;
 	}
@@ -274,45 +264,60 @@ static void
 action_go_to_computer_callback (GtkAction *action, 
 				gpointer user_data) 
 {
+	GFile *computer;
+	computer = g_file_new_for_uri (COMPUTER_URI);
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
-			       COMPUTER_URI);
+			       computer);
+	g_object_unref (computer);
 }
 
 static void
 action_go_to_network_callback (GtkAction *action, 
 				gpointer user_data) 
 {
+	GFile *network;
+	network = g_file_new_for_uri (NETWORK_URI);
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
-			       NETWORK_URI);
+			       network);
+	g_object_unref (network);
 }
 
 static void
 action_go_to_templates_callback (GtkAction *action,
 				 gpointer user_data) 
 {
-	char *uri;
+	char *path;
+	GFile *location;
 
-	nautilus_create_templates_directory ();
-	uri = nautilus_get_templates_directory_uri ();
+	path = nautilus_get_templates_directory ();
+	location = g_file_new_for_path (path);
+	g_free (path);
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
-			       uri);
-	g_free (uri);
+			       location);
+	g_object_unref (location);
 }
 
 static void
 action_go_to_trash_callback (GtkAction *action, 
 			     gpointer user_data) 
 {
+	GFile *trash;
+	trash = g_file_new_for_uri ("trash:///");
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
-			       EEL_TRASH_URI);
+			       trash);
+	g_object_unref (trash);
 }
 
 static void
 action_go_to_burn_cd_callback (GtkAction *action,
 			       gpointer user_data) 
 {
+	GFile *burn;
+	burn = g_file_new_for_uri (BURN_CD_URI);
 	nautilus_window_go_to (NAUTILUS_WINDOW (user_data),
-			       BURN_CD_URI);
+			       burn);
+	g_object_unref (burn);
+	
 }
 
 static void
@@ -438,7 +443,11 @@ action_about_nautilus_callback (GtkAction *action,
 					     _(license[2]), NULL);
 
 	gtk_show_about_dialog (GTK_WINDOW (user_data),
+#if GTK_CHECK_VERSION (2, 11, 0)
+			       "program-name", _("Nautilus"),
+#else
 			       "name", _("Nautilus"),
+#endif /* GTK 2.11. 0 */
 			       "version", VERSION,
 			       "comments", _("Nautilus is a graphical shell "
 					     "for GNOME that makes it "
@@ -457,7 +466,7 @@ action_about_nautilus_callback (GtkAction *action,
 			      "translator-credits", _("translator-credits"),
 			      "logo-icon-name", "nautilus",
 			      "website", "http://www.gnome.org/projects/nautilus",
-			      "website-label", "Nautilus Website",			     
+			      "website-label", _("Nautilus Web Site"),
 			      NULL);
 
 	g_free (license_trans);
@@ -612,11 +621,11 @@ static const GtkActionEntry main_entries[] = {
     G_CALLBACK (action_up_callback) },
   { "Stop", GTK_STOCK_STOP,                        /* name, stock id */
     N_("_Stop"), NULL,           /* label, accelerator */
-    NULL,                                      /* tooltip */ 
+    N_("Stop loading the current location"), /* tooltip */
     G_CALLBACK (action_stop_callback) },
   { "Reload", GTK_STOCK_REFRESH,                        /* name, stock id */
     N_("_Reload"), "<control>R",           /* label, accelerator */
-    NULL,                                      /* tooltip */ 
+    N_("Reload the current location"),     /* tooltip */
     G_CALLBACK (action_reload_callback) },
   { "Nautilus Manual", GTK_STOCK_HELP,                        /* name, stock id */
     N_("_Contents"), "F1",           /* label, accelerator */
@@ -650,10 +659,12 @@ static const GtkActionEntry main_entries[] = {
     N_("Normal Si_ze"), "<control>0",           /* label, accelerator */
     N_("Show the contents at the normal size"),                                      /* tooltip */ 
     G_CALLBACK (action_zoom_normal_callback) },
+#ifdef GIO_CONVERSION_DONE
   { "Connect to Server", NULL,                        /* name, stock id */
     N_("Connect to _Server..."), NULL,           /* label, accelerator */
     N_("Connect to a remote computer or shared disk"),                                      /* tooltip */ 
     G_CALLBACK (action_connect_to_server_callback) },
+#endif
   { "Home", "gnome-fs-home",                        /* name, stock id */
     N_("_Home Folder"), "<alt>Home",           /* label, accelerator */
     N_("Open your personal folder"),                                  /* tooltip */ 
